@@ -19,7 +19,17 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ##################################################################################
 
-include("dati/dati.php");
+
+# Posizione delle cartelle "dati" e "scontri" rispetto alla cartella di fantacalciobazar. 
+# Cambiare SOLO SE queste cartelle non si trovano nella stessa cartella degli alti file 
+# di fantacalciobazar! Non mettere lo slash alla fine. La cartella "voti"  dove vengono 
+# posizionati i file votiXX.txt, di default la stessa "dati".
+$percorso_cartella_dati = "./dati";
+$percorso_cartella_scontri = "./scontri";
+$percorso_cartella_voti = $percorso_cartella_dati;
+
+
+include("$percorso_cartella_dati/dati.php");
 $pass_admin_errata = "SI";
 if ($nome_utente == "admin") {
 $pass_errata = "SI";
@@ -31,13 +41,13 @@ $pass_admin_errata = "NO";
 } # fine if ($nome_utente == "admin")
 else {
 if (!$pass[$nome_utente]) {
-echo "Nome utente o password errati.<br>";
+if ($parla != "NO") echo "Nome utente o password errati.<br>";
 $pass_errata = "SI";
 } # fine if (!$pass[$nome_utente])
 if ($pass[$nome_utente] == "nopasswordinserita") { $password = ""; }
 else { $password = $pass[$nome_utente]; }
 if ($pass_fornita != $password) {
-echo "Nome utente o password errati.<br>";
+if ($parla != "NO") echo "Nome utente o password errati.<br>";
 $pass_errata = "SI";
 } # fine if ($pass_fornita != $password)
 } # fine else if ($nome_utente == "admin")
