@@ -32,10 +32,10 @@ $soldi_spesi = 0;
 $vecchio_proprietario = "";
 $nuovo_costo = "";
 $num_calciatori_posseduti = 0;
-$lock = fopen("dati/mercato.lock","w+");
+$lock = fopen("$percorso_cartella_dati/mercato.lock","w+");
 flock($lock,2);
 
-$calciatori = @file("dati/mercato.txt");
+$calciatori = @file("$percorso_cartella_dati/mercato.txt");
 $num_calciatori = count($calciatori);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 $dati_calciatore = explode(",", $calciatori[$num1]);
@@ -82,8 +82,9 @@ $frase .= "L'offerta non  abbastanza alta per comprare il calciatore.<br>";
 } # fine for $num1
 
 if ($trovato != "SI") {
+$nuova_offerta = "SI";
 $sostituire = "NO";
-$calciatori_completi = file("dati/calciatori.txt");
+$calciatori_completi = file("$percorso_cartella_dati/calciatori.txt");
 $num_calciatori_completi = count($calciatori_completi);
 for ($num1 = 0 ; $num1 < $num_calciatori_completi ; $num1++) {
 $dati_calciatore = explode($separatore_campi_file_calciatori, $calciatori_completi[$num1]);
@@ -112,14 +113,24 @@ $inserire = "NO";
 $frase .= "Calciatore inesistente, sei un BARO!<br>";
 } # fine if ($trovato != "SI")
 
-$verifica_num = ereg_replace("[0-9]","",$valore_offerta);
-if ($verifica_num != "") {
+if ($nuova_offerta == "SI" and $stato_mercato == "S") {
 $inserire = "NO";
-$frase .= "L'offerta deve essere un numero intero.<br>";
-} # fine if ($verifica_num != "")
+echo "<center>Il mercato  <b>sospeso</b> in questo momento.</center><br>";
+} # fine if ($nuova_offerta == "SI" and $stato_mercato == "S")
+
+if ($stato_mercato == "C") {
+$inserire = "NO";
+echo "<center>Il mercato  <b>chiuso</b> in questo momento.</center><br>";
+} # fine if ($stato_mercato == "C")
+
+$verifica_num = ereg_replace("[0-9]","",$valore_offerta);
+if ($verifica_num != "" or $valore_offerta == "" or $valore_offerta == 0) {
+$inserire = "NO";
+$frase .= "L'offerta deve essere un numero intero positivo.<br>";
+} # fine if ($verifica_num != "" or $valore_offerta == "" or $valore_offerta == 0)
 
 $num_calciatori_comprabili = $max_calciatori - $num_calciatori_posseduti;
-$surplus = @file("dati/squadra_$nome_utente");
+$surplus = @file("$percorso_cartella_dati/squadra_$nome_utente");
 $surplus = $surplus[0];
 if ($vecchio_proprietario == $nome_utente and $vecchio_proprietario != $proprietario_vero) {
 $surplus = $surplus - $costo + $vecchio_costo;
@@ -141,7 +152,7 @@ if ($sostituire == "NO") {
 $posizione == 0;
 $num_calciatori++;
 } # fine if ($sostituire == "NO")
-$file_mercato = fopen("dati/mercato.txt","w+");
+$file_mercato = fopen("$percorso_cartella_dati/mercato.txt","w+");
 flock($file_mercato,2);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 
@@ -166,10 +177,10 @@ $aggiungi_surplus = $valore_offerta - $vecchio_costo;
 } # fine if ($vecchio_proprietario == $proprietario_vero)
 else { $aggiungi_surplus = $valore_offerta - $costo; }
 } # fine else if ($vecchio_proprietario == $nome_utente)
-$lockutente = fopen("dati/squadra_$vecchio_proprietario.lock","w+");
+$lockutente = fopen("$percorso_cartella_dati/squadra_$vecchio_proprietario.lock","w+");
 flock($lockutente,2);
-$linee = @file("dati/squadra_$vecchio_proprietario");
-$filesquadra = fopen("dati/squadra_$vecchio_proprietario","w+");
+$linee = @file("$percorso_cartella_dati/squadra_$vecchio_proprietario");
+$filesquadra = fopen("$percorso_cartella_dati/squadra_$vecchio_proprietario","w+");
 flock($filesquadra,2);
 $num_linee = count($linee);
 if ($num_linee < 1) { $num_linee = 1; }
