@@ -19,31 +19,35 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ##################################################################################
 
-include("dati/head.php");
 
+$parla = "NO";
+if ($cambia_pass) $parla = "SI";
+include("controlla_pass.php");
 
 if ($cambia_pass) {
 
-include("controlla_pass.php");
 if ($pass_errata == "SI") { $cambiare = "NO"; }
-if ($pass_admin_errata == "NO") { $cambiare = "SI"; }
+if ($nome_utente == "admin") {
+if ($pass_admin_errata == "NO") $cambiare = "SI";
+} # fine if ($nome_utente == "admin")
 if ($nuova_pass1 != $nuova_pass2 and $cambiare != "NO") {
 echo "Le nuove password non coincidno.<br>";
 $cambiare = "NO";
 } # fine if ($nuova_pass1 != $nuova_pass2 and ...)
 
 if ($cambiare != "NO") {
-$lock = fopen("dati/pass.lock","w+");
+if ($nuova_pass1 == "") $nuova_pass1 = "nopasswordinserita";
+$lock = fopen("$percorso_cartella_dati/pass.lock","w+");
 flock($lock,2);
-$linee_pass = file("dati/dati.php");
-$filepass = fopen("dati/dati.php","w+");
+$linee_pass = file("$percorso_cartella_dati/dati.php");
+$filepass = fopen("$percorso_cartella_dati/dati.php","w+");
 flock($filepass,2);
 $num_linee_pass = count($linee_pass);
-$lung_nome_utente = strlen($nome_utente) + 1;
+$lung_nome_utente = strlen($nome_utente) + 3;
 for ($num1 = 0 ; $num1 < $num_linee_pass; $num1++) {
 if ($nome_utente == "admin") {
-$stringa = substr($linee_pass[$num1],1,9);
-if ($stringa == "passadmin") {
+$stringa = substr($linee_pass[$num1],0,10);
+if ($stringa == "\$passadmin") {
 $linee_pass[$num1] = "\$passadmin = \"$nuova_pass1\";
 ";
 break;
@@ -51,8 +55,8 @@ break;
 } # fine if ($nome_utente == "admin")
 else {
 $stringa = substr($linee_pass[$num1],6,$lung_nome_utente);
-if ($stringa == $nome_utente."]") {
-$linee_pass[$num1] = "\$pass[$nome_utente] = \"$nuova_pass1\";
+if ($stringa == "\"".$nome_utente."\"]") {
+$linee_pass[$num1] = "\$pass[\"$nome_utente\"] = \"$nuova_pass1\";
 ";
 break;
 } # fine if ($stringa == $nome_utente."]")
@@ -76,7 +80,7 @@ echo "<form method=\"post\" action=\"login.php\">
 
 else {
 
-include("dati/dati.php");
+include("$percorso_cartella_dati/dati.php");
 $pass = "";
 $passadmin = "";
 
@@ -92,7 +96,7 @@ echo "<form method=\"post\" action=\"guarda_giornata.php\">
 for ($num1 = "01" ; $num1 < 100 ; $num1++) {
 if (strlen($num1) == 1) $num1 = "0".$num1;
 $giornata = "giornata$num1";
-if (is_file("dati/$giornata")) {
+if (is_file("$percorso_cartella_dati/$giornata")) {
 echo "<option value=\"giornata$num1\">$num1</option>";
 } # fine if (is_dir($giornata))
 else break;
@@ -115,5 +119,5 @@ Ripeti la nuova password: <input type=\"password\" name=\"nuova_pass2\" size=\"9
 
 } # fine else if ($cambia_pass)
 
-include("dati/foot.php");
+include("$percorso_cartella_dati/foot.php");
 ?>
