@@ -19,14 +19,16 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ##################################################################################
 
-include("dati/head.php");
 
 include("controlla_pass.php");
+include("$percorso_cartella_dati/head.php");
 if ($pass_errata != "SI") {
 
 
 
-$calciatori = @file("dati/mercato.txt");
+if ($sfondo_tab == "") $sfondo_tab = "#b9ccd4";
+
+$calciatori = @file("$percorso_cartella_dati/mercato.txt");
 $num_calciatori = count($calciatori);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 $dati_calciatore = explode(",", $calciatori[$num1]);
@@ -36,7 +38,7 @@ $nomi[$numero] = $nome;
 } # fine for $num1
 
 echo "<center><font size=+2>Proposte di scambio</font></center><br><font size=-1>
-<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"#b9ccd4\">
+<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
 <tr><td><font size=-1>offerta_di</font></td>
 <td>_______offerta_______</td>
 <td><font size=-1>offerta_per</font></td>
@@ -44,7 +46,7 @@ echo "<center><font size=+2>Proposte di scambio</font></center><br><font size=-1
 <td><font size=-1>__Tempo_rimasto__</font></td>
 <td><font size=-1>&nbsp;</font></td></tr>";
 
-$scambi_proposti = @file("dati/scambi.txt");
+$scambi_proposti = @file("$percorso_cartella_dati/scambi.txt");
 $num_scambi_proposti = count($scambi_proposti);
 
 for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
@@ -87,7 +89,7 @@ if ($nome == "") $nome = "???";
 if ($num2 == 0) $offerta = $nome;
 else $offerta .= ", ".$nome;
 } # fine for $num2
-if ($soldi_offerti != 0) $offerta .= ", ".$soldi_offerti." Euro";
+if ($soldi_offerti != 0) $offerta .= ", ".$soldi_offerti." Fanta-Euro";
 for ($num2 = 0 ; $num2 < $num_calciatori_richiesti ; $num2++) {
 $numero = $calciatori_richiesti[$num2];
 $nome = $nomi[$numero];
@@ -95,7 +97,7 @@ if ($nome == "") $nome = "???";
 if ($num2 == 0) $richiesta = $nome;
 else $richiesta .= ", ".$nome;
 } # fine for $num2
-if ($soldi_richiesti != 0) $richiesta .= ", ".$soldi_richiesti." Euro";
+if ($soldi_richiesti != 0) $richiesta .= ", ".$soldi_richiesti." Fanta-Euro";
 
 if ($utente_richiesto == $nome_utente) $accetta = "<a href=\"scambio_accetta.php?id_scambio=$id_scambio&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">accetta</a>";
 else $accetta = "&nbsp;";
@@ -122,5 +124,5 @@ echo "<br><br><center><form method=\"post\" action=\"mercato.php\">
 
 } # fine if ($pass_errata != "SI")
 
-include("dati/foot.php");
+include("$percorso_cartella_dati/foot.php");
 ?>
