@@ -19,16 +19,16 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ##################################################################################
 
-include("dati/head.php");
 
 include("controlla_pass.php");
+include("$percorso_cartella_dati/head.php");
 if ($pass_errata != "SI") {
 
 
 
-$lock = fopen("dati/mercato.lock","w+");
+$lock = fopen("$percorso_cartella_dati/mercato.lock","w+");
 flock($lock,2);
-$lock2 = fopen("dati/scambi.lock","w+");
+$lock2 = fopen("$percorso_cartella_dati/scambi.lock","w+");
 flock($lock2,2);
 
 $trovato = "NO";
@@ -49,7 +49,7 @@ $lista_ric = "";
 $ini_lista_off = "";
 $ini_lista_ric = "";
 
-$scambi_proposti = @file("dati/scambi.txt");
+$scambi_proposti = @file("$percorso_cartella_dati/scambi.txt");
 $num_scambi_proposti = count($scambi_proposti);
 
 for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
@@ -87,6 +87,13 @@ if ($trovato == "NO") echo "Proposta di scambio non trovata.<br>";
 else {
 
 
+if ($stato_mercato == "C") {
+echo "<center>Il mercato  <b>chiuso</b> in questo momento.</center><br>";
+} # fine if ($stato_mercato == "C")
+
+else {
+
+
 if (!$sicuro) {
 echo "<form method=\"post\" action=\"$SCRIPT_NAME\">
 Sei sicuro di voler accettare lo scambio proposto da <b>$utente_offerente</b>?&nbsp;
@@ -100,12 +107,12 @@ Sei sicuro di voler accettare lo scambio proposto da <b>$utente_offerente</b>?&n
 else {
 
 
-$lock3 = fopen("dati/squadra_$nome_utente.lock","w+");
+$lock3 = fopen("$percorso_cartella_dati/squadra_$nome_utente.lock","w+");
 flock($lock3,2);
-$lock4 = fopen("dati/squadra_$utente_offerente.lock","w+");
+$lock4 = fopen("$percorso_cartella_dati/squadra_$utente_offerente.lock","w+");
 flock($lock4,2);
 
-$calciatori = @file("dati/mercato.txt");
+$calciatori = @file("$percorso_cartella_dati/mercato.txt");
 $num_calciatori = count($calciatori);
 
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
@@ -174,14 +181,14 @@ $scambiare = "NO";
 echo "Dopo lo scambio $utente_offerente avrebbe pi di $max_calciatori calciatori.<br>";
 } # fine if ($num_calciatori_dopo > $max_calciatori)
 
-$surplus = @file("dati/squadra_$nome_utente");
+$surplus = @file("$percorso_cartella_dati/squadra_$nome_utente");
 $surplus = $surplus[0];
 $soldi_spendibili = $soldi_iniziali + $surplus - $soldi_spesi;
 if ($soldi_richiesti > $soldi_spendibili) {
 $scambiare = "NO";
 echo "Ti sono richiesti pi soldi di quelli da te posseduti.<br>";
 } # fine if ($soldi_richiesti > $soldi_spendibili)
-$surplus_altro = @file("dati/squadra_$utente_offerente");
+$surplus_altro = @file("$percorso_cartella_dati/squadra_$utente_offerente");
 $surplus_altro = $surplus_altro[0];
 $soldi_spendibili_altro = $soldi_iniziali + $surplus_altro - $soldi_spesi_altro;
 if ($soldi_offerti > $soldi_spendibili_altro) {
@@ -192,7 +199,7 @@ echo "I soldi offerti sono pi di quelli posseduti da $utente_offerente.<br>";
 # se i controlli sono andati bene effettuo lo scambio
 if ($scambiare != "NO") {
 
-$file_mercato = fopen("dati/mercato.txt","w+");
+$file_mercato = fopen("$percorso_cartella_dati/mercato.txt","w+");
 flock($file_mercato,2);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 $dati_calciatore = explode(",", $calciatori[$num1]);
@@ -236,8 +243,8 @@ flock($file_mercato,3);
 fclose($file_mercato);
 
 $aggiungi_surplus = $costo_calciatori_offerti - $costo_calciatori_richiesti + $soldi_offerti - $soldi_richiesti;
-$linee = @file("dati/squadra_$nome_utente");
-$filesquadra = fopen("dati/squadra_$nome_utente","w+");
+$linee = @file("$percorso_cartella_dati/squadra_$nome_utente");
+$filesquadra = fopen("$percorso_cartella_dati/squadra_$nome_utente","w+");
 flock($filesquadra,2);
 $num_linee = count($linee);
 if ($num_linee < 1) { $num_linee = 1; }
@@ -252,8 +259,8 @@ flock($filesquadra,3);
 fclose($filesquadra);
 
 $aggiungi_surplus = $costo_calciatori_richiesti - $costo_calciatori_offerti + $soldi_richiesti - $soldi_offerti;
-$linee = @file("dati/squadra_$utente_offerente");
-$filesquadra = fopen("dati/squadra_$utente_offerente","w+");
+$linee = @file("$percorso_cartella_dati/squadra_$utente_offerente");
+$filesquadra = fopen("$percorso_cartella_dati/squadra_$utente_offerente","w+");
 flock($filesquadra,2);
 $num_linee = count($linee);
 if ($num_linee < 1) { $num_linee = 1; }
@@ -267,9 +274,9 @@ fwrite($filesquadra,$linee[$num1]);
 flock($filesquadra,3);
 fclose($filesquadra);
 
-$scambi_proposti = @file("dati/scambi.txt");
+$scambi_proposti = @file("$percorso_cartella_dati/scambi.txt");
 $num_scambi_proposti = count($scambi_proposti);
-$file_scambi = fopen("dati/scambi.txt","w+");
+$file_scambi = fopen("$percorso_cartella_dati/scambi.txt","w+");
 flock($file_scambi,2);
 $adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
 for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
@@ -292,7 +299,7 @@ fclose($file_scambi);
 if ($soldi_richiesti != 0) $lista_ric .= " + $soldi_richiesti Euro";
 if ($soldi_offerti != 0) $lista_off .= " + $soldi_offerti Euro";
 $nuovo_messaggio = "$nome_utente ha accettato lo scambio proposto da $utente_offerente per $lista_ric in cambio di $lista_off";
-$file_messaggi = fopen("dati/messaggi.txt","a+");
+$file_messaggi = fopen("$percorso_cartella_dati/messaggi.txt","a+");
 flock($file_messaggi,2);
 fwrite($file_messaggi,"Radio mercato#@?".$nuovo_messaggio."
 ");
@@ -311,6 +318,8 @@ fclose($lock3);
 
 } # fine else if (!$sicuro)
 
+} # fine else if ($stato_mercato == "C")
+
 } # fine else if ($trovato == "NO")
 
 
@@ -329,5 +338,5 @@ echo "<br><br><center><form method=\"post\" action=\"mercato.php\">
 
 } # fine if ($pass_errata != "SI")
 
-include("dati/foot.php");
+include("$percorso_cartella_dati/foot.php");
 ?>
\ No newline at end of file
