@@ -37,7 +37,7 @@ $num_titolari_A = 0;
 $num_panchinari = 0;
 $num_in_panchina_usati = "";
 
-$calciatori = file("dati/mercato.txt");
+$calciatori = file("$percorso_cartella_dati/mercato.txt");
 $num_calciatori = count($calciatori);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 $dati_calciatore = explode(",", $calciatori[$num1]);
@@ -133,10 +133,10 @@ if ($num_titolari_A > $max_num_cons_A) { $inserire = "NO"; $frase .= "Troppi att
 } # fine if ($num_titolari < 11)
 
 if ($inserire != "NO") {
-$lock = fopen("dati/squadra_$nome_utente.lock","w+");
+$lock = fopen("$percorso_cartella_dati/squadra_$nome_utente.lock","w+");
 flock($lock,2);
-$linee = @file("dati/squadra_$nome_utente");
-$filesquadra = fopen("dati/squadra_$nome_utente","w+");
+$linee = @file("$percorso_cartella_dati/squadra_$nome_utente");
+$filesquadra = fopen("$percorso_cartella_dati/squadra_$nome_utente","w+");
 flock($filesquadra,2);
 $num_linee = count($linee);
 if ($num_linee < 3) { $num_linee = 3; }
