@@ -19,9 +19,9 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ##################################################################################
 
-include("dati/head.php");
 
 include("controlla_pass.php");
+include("$percorso_cartella_dati/head.php");
 if ($pass_errata != "SI") {
 
 
@@ -29,7 +29,7 @@ if ($pass_errata != "SI") {
 $trovato = "NO";
 $num_calciatori_posseduti = 0;
 $soldi_spesi = 0;
-$calciatori = file("dati/mercato.txt");
+$calciatori = file("$percorso_cartella_dati/mercato.txt");
 $num_calciatori = count($calciatori);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 $dati_calciatore = explode(",", $calciatori[$num1]);
@@ -60,6 +60,9 @@ if ($trovato == "NO") {
 echo "Non puoi vendere questo calciatore.<br>";
 } # fine if ($trovato == "NO")
 
+else {
+if ($stato_mercato == "S") echo "<center>Il mercato  <b>sospeso</b> in questo momento.</center><br>";
+if ($stato_mercato == "C") echo "<center>Il mercato  <b>chiuso</b> in questo momento.</center><br>";
 else {
 $prezzo_vendita = floor(($costo/100)*$percentuale_vendita);
 echo "<form method=\"post\" action=\"vendi_subito.php\">
@@ -67,16 +70,19 @@ echo "<form method=\"post\" action=\"vendi_subito.php\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"hidden\" name=\"num_calciatore\" value=\"$num_calciatore\">
 <input type=\"submit\" name=\"vendi_subito\" value=\"Vendi subito\">
- il calciatore <b>$nome</b> per <b>$prezzo_vendita</b> Euro (comprato a <b>$costo</b> Euro).<br>
-</form>
-<form method=\"post\" action=\"vendi_sul_mercato.php\">
+ il calciatore <b>$nome</b> per <b>$prezzo_vendita</b> Fanta-Euro (comprato a <b>$costo</b> Fanta-Euro).<br>
+</form>";
+if ($stato_mercato != "S") {
+echo "<form method=\"post\" action=\"vendi_sul_mercato.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"hidden\" name=\"num_calciatore\" value=\"$num_calciatore\">
 <input type=\"submit\" name=\"rivendi\" value=\"Rimetti sul mercato\">
  il calciatore <b>$nome</b> per almeno
-<input type=\"text\" name=\"valore_rivendita\" size=\"8\">  Euro.<br>
+<input type=\"text\" name=\"valore_rivendita\" size=\"8\">  Fanta-Euro.<br>
 </form>";
+} # fine if ($stato_mercato != "S")
+} # fine else if ($stato_mercato == "C")
 } # fine else if ($trovato == "NO")
 
 echo "<center><form method=\"post\" action=\"squadra.php\">
@@ -90,5 +96,5 @@ echo "<center><form method=\"post\" action=\"squadra.php\">
 
 } # fine if ($pass_errata != "SI")
 
-include("dati/foot.php");
+include("$percorso_cartella_dati/foot.php");
 ?>
