@@ -24,11 +24,11 @@ if ($pass_errata != "SI") {
 
 
 
-$lock = fopen("dati/mercato.lock","w+");
+$lock = fopen("$percorso_cartella_dati/mercato.lock","w+");
 flock($lock,2);
 
 $trovato = "NO";
-$calciatori = file("dati/mercato.txt");
+$calciatori = file("$percorso_cartella_dati/mercato.txt");
 $num_calciatori = count($calciatori);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 $dati_calciatore = explode(",", $calciatori[$num1]);
@@ -56,20 +56,25 @@ $posizione = $num1;
 } # fine if ($proprietario == $nome_utente)
 } # fine for $num1
 
+if ($stato_mercato == "C") {
+$trovato = "NO";
+$frase = "Il mercato  <b>chiuso</b> in questo momento.<br>";
+} # fine if ($stato_mercato == "C")
+
 if ($trovato == "NO") {
 echo "<html>
 <header>
 <title> Fantacalcio </title>
 </header>
 <body bgcolor=#ffffff>
-Non puoi vendere questo calciatore.<br>";
+Non puoi vendere questo calciatore.<br>$frase";
 } # fine if ($trovato == "NO")
 
 else {
 $prezzo_vendita = floor(($costo/100)*$percentuale_vendita);
 $aggiungi_surplus = $prezzo_vendita - $costo; 
 
-$file_mercato = fopen("dati/mercato.txt","w+");
+$file_mercato = fopen("$percorso_cartella_dati/mercato.txt","w+");
 flock($file_mercato,2);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 if ($posizione != $num1) {
@@ -79,10 +84,10 @@ fwrite($file_mercato,$calciatori[$num1]);
 flock($file_mercato,3);
 fclose($file_mercato);
 
-$lockutente = fopen("dati/squadra_$nome_utente.lock","w+");
+$lockutente = fopen("$percorso_cartella_dati/squadra_$nome_utente.lock","w+");
 flock($lockutente,2);
-$linee = @file("dati/squadra_$nome_utente");
-$filesquadra = fopen("dati/squadra_$nome_utente","w+");
+$linee = @file("$percorso_cartella_dati/squadra_$nome_utente");
+$filesquadra = fopen("$percorso_cartella_dati/squadra_$nome_utente","w+");
 flock($filesquadra,2);
 $num_linee = count($linee);
 if ($num_linee < 1) { $num_linee = 1; }
@@ -96,8 +101,8 @@ fwrite($filesquadra,$linee[$num1]);
 flock($filesquadra,3);
 flock($lockutente,3);
 
-$nuovo_messaggio = "$nome_utente ha venduto $nome per $prezzo_vendita Euro";
-$file_messaggi = fopen("dati/messaggi.txt","a+");
+$nuovo_messaggio = "$nome_utente ha venduto $nome per $prezzo_vendita Fanta-Euro";
+$file_messaggi = fopen("$percorso_cartella_dati/messaggi.txt","a+");
 flock($file_messaggi,2);
 fwrite($file_messaggi,"Radio mercato#@?".$nuovo_messaggio."
 ");
