@@ -24,11 +24,11 @@ if ($pass_errata != "SI") {
 
 
 
-$lock = fopen("dati/mercato.lock","w+");
+$lock = fopen("$percorso_cartella_dati/mercato.lock","w+");
 flock($lock,2);
 
 $trovato = "NO";
-$calciatori = file("dati/mercato.txt");
+$calciatori = file("$percorso_cartella_dati/mercato.txt");
 $num_calciatori = count($calciatori);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 $dati_calciatore = explode(",", $calciatori[$num1]);
@@ -62,6 +62,11 @@ $trovato = "NO";
 $frase = "L'offerta deve essere un numero intero.<br>";
 } # fine if ($verifica_num != "")
 
+if ($stato_mercato == "C" or $stato_mercato == "S") {
+$trovato = "NO";
+$frase .= "Il mercato  <b>chiuso</b> o <b>sospeso</b> in questo momento.<br>";
+} # fine if ($stato_mercato == "C" or $stato_mercato == "S")
+
 if ($trovato == "NO") {
 echo "<html>
 <header>
@@ -73,7 +78,7 @@ Non puoi vendere questo calciatore.<br>$frase";
 
 else { 
 
-$file_mercato = fopen("dati/mercato.txt","w+");
+$file_mercato = fopen("$percorso_cartella_dati/mercato.txt","w+");
 flock($file_mercato,2);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 if ($posizione != $num1) {
@@ -95,10 +100,10 @@ fwrite($file_mercato,"$linea
 flock($file_mercato,3);
 fclose($file_mercato);
 
-$lockutente = fopen("dati/squadra_$nome_utente.lock","w+");
+$lockutente = fopen("$percorso_cartella_dati/squadra_$nome_utente.lock","w+");
 flock($lockutente,2);
-$linee = @file("dati/squadra_$nome_utente");
-$filesquadra = fopen("dati/squadra_$nome_utente","w+");
+$linee = @file("$percorso_cartella_dati/squadra_$nome_utente");
+$filesquadra = fopen("$percorso_cartella_dati/squadra_$nome_utente","w+");
 flock($filesquadra,2);
 $num_linee = count($linee);
 if ($num_linee < 1) { $num_linee = 1; }
@@ -118,7 +123,7 @@ echo "<html>
 <meta http-equiv=\"refresh\" content=\"1; url=squadra.php?nome_squadra=$nome_utente&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">
 </header>
 <body bgcolor=#ffffff>
-Calciatore rimesso sul mercato per <b>$valore_rivendita</b> Euro!<br>";
+Calciatore rimesso sul mercato per <b>$valore_rivendita</b> Fanta-Euro!<br>";
 } # fine else if ($trovato == "NO")
 
 echo "<center><form method=\"post\" action=\"squadra.php\">
